-- Copyright (c) 2016-present, Facebook, Inc.
-- All rights reserved.
--
-- This source code is licensed under the BSD-style license found in the
-- LICENSE file in the root directory of this source tree. An additional grant
-- of patent rights can be found in the PATENTS file in the same directory.


{-# LANGUAGE GADTs #-}
{-# LANGUAGE OverloadedStrings #-}

module Duckling.Rules.FR
  ( defaultRules
  , langRules
  , localeRules
  ) where

import Duckling.Dimensions.Types
import Duckling.Locale
import Duckling.Types
import qualified Duckling.AmountOfMoney.FR.Rules as AmountOfMoney
import qualified Duckling.Distance.FR.Rules as Distance
import qualified Duckling.Duration.FR.Rules as Duration
import qualified Duckling.Email.FR.Rules as Email
import qualified Duckling.Numeral.FR.Rules as Numeral
import qualified Duckling.Ordinal.FR.Rules as Ordinal
import qualified Duckling.Quantity.FR.Rules as Quantity
import qualified Duckling.Temperature.FR.Rules as Temperature
import qualified Duckling.Time.FR.Rules as Time
import qualified Duckling.TimeGrain.FR.Rules as TimeGrain
import qualified Duckling.Volume.FR.Rules as Volume

defaultRules :: Some Dimension -> [Rule]
defaultRules = langRules

localeRules :: Region -> Some Dimension -> [Rule]
localeRules _ _ = []

langRules :: Some Dimension -> [Rule]
langRules (This AmountOfMoney) = AmountOfMoney.rules
langRules (This Distance) = Distance.rules
langRules (This Duration) = Duration.rules
langRules (This Email) = Email.rules
langRules (This Numeral) = Numeral.rules
langRules (This Ordinal) = Ordinal.rules
langRules (This PhoneNumber) = []
langRules (This Quantity) = Quantity.rules
langRules (This RegexMatch) = []
langRules (This Temperature) = Temperature.rules
langRules (This Time) = Time.rules
langRules (This TimeGrain) = TimeGrain.rules
langRules (This Url) = []
langRules (This Volume) = Volume.rules
